@@ -7,6 +7,7 @@ use std::slice;
 use datachannel_sys as sys;
 
 use crate::error::{check, Error, Result};
+use crate::logger;
 
 #[derive(Debug, Clone, Default)]
 pub struct Reliability {
@@ -221,7 +222,7 @@ where
             Ok(_) => match crate::ffi_string(&buf) {
                 Ok(label) => label,
                 Err(err) => {
-                    log::error!(
+                    logger::error!(
                         "Couldn't get label for RtcDataChannel id={} {:p}, {}",
                         self.id,
                         self,
@@ -232,7 +233,7 @@ where
             },
 
             Err(err) => {
-                log::warn!(
+                logger::warn!(
                     "Couldn't get label for RtcDataChannel id={} {:p}, {}",
                     self.id,
                     self,
@@ -261,7 +262,7 @@ where
             Ok(_) => match crate::ffi_string(&buf) {
                 Ok(protocol) => Some(protocol),
                 Err(err) => {
-                    log::error!(
+                    logger::error!(
                         "Couldn't get protocol for RtcDataChannel id={} {:p}, {}",
                         self.id,
                         self,
@@ -271,7 +272,7 @@ where
                 }
             },
             Err(err) => {
-                log::warn!(
+                logger::warn!(
                     "Couldn't get protocol for RtcDataChannel id={} {:p}, {}",
                     self.id,
                     self,
@@ -310,7 +311,7 @@ where
         match check(unsafe { sys::rtcGetBufferedAmount(self.id) }) {
             Ok(amount) => amount as usize,
             Err(err) => {
-                log::error!(
+                logger::error!(
                     "Couldn't get buffered_amount for RtcDataChannel id={} {:p}, {}",
                     self.id,
                     self,
@@ -346,7 +347,7 @@ where
         match check(unsafe { sys::rtcGetAvailableAmount(self.id) }) {
             Ok(amount) => amount as usize,
             Err(err) => {
-                log::error!(
+                logger::error!(
                     "Couldn't get available_amount for RtcDataChannel id={} {:p}, {}",
                     self.id,
                     self,
@@ -360,14 +361,13 @@ where
 
 impl<D> Drop for RtcDataChannel<D> {
     fn drop(&mut self) {
-        match check(unsafe { sys::rtcDeleteDataChannel(self.id) }) {
-            Err(err) => log::error!(
+        if let Err(err) = check(unsafe { sys::rtcDeleteDataChannel(self.id) }) {
+            logger::error!(
                 "Error while dropping RtcDataChannel id={} {:p}: {}",
                 self.id,
                 self,
                 err
-            ),
-            _ => (),
+            );
         }
     }
 }
