@@ -12,6 +12,7 @@ use webrtc_sdp::{media_type::SdpMedia, parse_sdp, SdpSession};
 use crate::config::RtcConfig;
 use crate::datachannel::{DataChannelHandler, DataChannelInit, RtcDataChannel};
 use crate::error::{check, Error, Result};
+use crate::logger;
 use crate::track::{RtcTrack, TrackHandler, TrackInit};
 
 #[derive(Debug, PartialEq)]
@@ -162,6 +163,7 @@ pub struct IceCandidate {
 }
 
 #[allow(unused_variables)]
+#[allow(clippy::boxed_local)]
 pub trait PeerConnectionHandler {
     type DCH;
 
@@ -187,6 +189,7 @@ where
     P::DCH: DataChannelHandler + Send,
 {
     pub fn new(config: &RtcConfig, pc_handler: P) -> Result<Box<Self>> {
+        #[cfg(feature = "log")]
         crate::ensure_logging();
 
         unsafe {
@@ -246,8 +249,8 @@ where
         let sdp = match parse_sdp(&sdp, false) {
             Ok(sdp) => sdp,
             Err(err) => {
-                log::warn!("Ignoring invalid SDP: {}", err);
-                log::debug!("{}", sdp);
+                logger::warn!("Ignoring invalid SDP: {}", err);
+                logger::debug!("{}", sdp);
                 return;
             }
         };
@@ -256,8 +259,8 @@ where
         let sdp_type = match SdpType::from(&sdp_type) {
             Ok(sdp_type) => sdp_type,
             Err(_) => {
-                log::warn!("Ignoring session with invalid SdpType: {}", sdp_type);
-                log::debug!("{}", sdp);
+                logger::warn!("Ignoring session with invalid SdpType: {}", sdp_type);
+                logger::debug!("{}", sdp);
                 return;
             }
         };
@@ -323,7 +326,7 @@ where
                 let _guard = rtc_pc.lock.lock();
                 rtc_pc.pc_handler.on_data_channel(dc);
             }
-            Err(err) => log::error!(
+            Err(err) => logger::error!(
                 "Couldn't create RtcDataChannel with id={} from RtcPeerConnection {:p}: {}",
                 id,
                 ptr,
@@ -413,7 +416,7 @@ where
         match (sdp, sdp_type) {
             (Some(Ok(sdp)), Some(Ok(sdp_type))) => Some(SessionDescription { sdp, sdp_type }),
             (Some(Err(e)), _) | (None, Some(Err(e))) => {
-                log::error!("Got an invalid Sessiondescription: {}", e);
+                logger::error!("Got an invalid Sessiondescription: {}", e);
                 None
             }
             _ => None,
@@ -432,7 +435,7 @@ where
         match (sdp, sdp_type) {
             (Some(Ok(sdp)), Some(Ok(sdp_type))) => Some(SessionDescription { sdp, sdp_type }),
             (Some(Err(e)), _) | (None, Some(Err(e))) => {
-                log::error!("Got an invalid Sessiondescription: {}", e);
+                logger::error!("Got an invalid Sessiondescription: {}", e);
                 None
             }
             _ => None,
@@ -461,7 +464,7 @@ where
         let buf_size = match buf_size {
             Ok(buf_size) => buf_size as usize,
             Err(err) => {
-                log::error!("Couldn't get buffer size: {}", err);
+                logger::error!("Couldn't get buffer size: {}", err);
                 return None;
             }
         };
@@ -483,7 +486,7 @@ where
                 match (local, remote) {
                     (Ok(local), Ok(remote)) => Some(CandidatePair { local, remote }),
                     (Ok(_), Err(err)) | (Err(err), Ok(_)) | (Err(err), Err(_)) => {
-                        log::error!(
+                        logger::error!(
                             "Couldn't get RtcPeerConnection {:p} candidate_pair: {}",
                             self,
                             err
@@ -494,7 +497,7 @@ where
             }
             Err(Error::NotAvailable) => None,
             Err(err) => {
-                log::warn!(
+                logger::warn!(
                     "Couldn't get RtcPeerConnection {:p} candidate_pair: {}",
                     self,
                     err
@@ -512,7 +515,7 @@ where
         let buf_size = match check(unsafe { str_fn(self.id, ptr::null_mut() as *mut c_char, 0) }) {
             Ok(buf_size) => buf_size as usize,
             Err(err) => {
-                log::error!("Couldn't get buffer size: {}", err);
+                logger::error!("Couldn't get buffer size: {}", err);
                 return None;
             }
         };
@@ -522,7 +525,7 @@ where
             Ok(_) => match String::from_utf8(buf) {
                 Ok(local) => Some(local.trim_matches(char::from(0)).to_string()),
                 Err(err) => {
-                    log::error!(
+                    logger::error!(
                         "Couldn't get RtcPeerConnection {:p} {}: {}",
                         self,
                         prop,
@@ -533,7 +536,7 @@ where
             },
             Err(Error::NotAvailable) => None,
             Err(err) => {
-                log::warn!(
+                logger::warn!(
                     "Couldn't get RtcPeerConnection {:p} {}: {}",
                     self,
                     prop,
@@ -547,14 +550,13 @@ where
 
 impl<P> Drop for RtcPeerConnection<P> {
     fn drop(&mut self) {
-        match check(unsafe { sys::rtcDeletePeerConnection(self.id) }) {
-            Err(err) => log::error!(
+        if let Err(err) = check(unsafe { sys::rtcDeletePeerConnection(self.id) }) {
+            logger::error!(
                 "Error while dropping RtcPeerConnection id={} {:p}: {}",
                 self.id,
                 self,
                 err
-            ),
-            _ => (),
+            )
         }
     }
 }
